@@ -41,11 +41,11 @@ class EvntalySDK:
             print("Tracking is disabled. Event not sent.")
             return
 
-        if self.check_limit():
+        if not self.check_limit():
             print("checkLimit returned false. Event not sent.")
             return
 
-        url = f"{self.BASE_URL}/api/v1/register/user"
+        url = f"{self.BASE_URL}/api/v1/register/event"
         headers = {
             "Content-Type": "application/json",
             "secret": self.developer_secret,
